@@ -1,9 +1,10 @@
+use 5.008;
 package IO::Interactive;
 
 use strict;
 use warnings;
 
-$IO::Interactive::VERSION = '1.021';
+$IO::Interactive::VERSION = '1.025';
 
 sub is_interactive {
     my ($out_handle) = (@_, select);    # Default to default output handle
@@ -119,9 +120,10 @@ sub import {
     for my $request ( @_ ) {
         no strict 'refs';
         my $impl = *{$package.'::'.$request}{CODE};
-        require Carp;
-        Carp::croak "Unknown subroutine ($request()) requested"
-            if !$impl || $request =~ m/\A _/xms;
+        if(!$impl || $request =~ m/\A _/xms) {
+            require Carp;
+            Carp::croak("Unknown subroutine ($request()) requested");
+        }
         *{$caller.'::'.$request} = $impl;
     }
 }
@@ -160,7 +162,18 @@ This document describes IO::Interactive version 1.02
 =head1 DESCRIPTION
 
 This module provides three utility subroutines that make it easier to
-develop interactive applications...
+develop interactive applications.
+
+The C<ARGV> filehandle, the one that C<< <> >> or an empty
+C<readline()> uses, has various magic associated with it. It's not
+actually opened until you try to read from it. Checking C<-t ARGV>
+before you've tried to read from it might give you the wrong answer.
+Not only that, you might not read from C<ARGV>. If the value in
+C<@ARGV> is the magic filename C<-> (a convention to mean the standard
+filehandle for input or output), C<ARGV> might actually be C<STDIN>.
+You don't want to think about all of this. This module is discussed in
+I<Perl Best Practices> on page 218. Also see the C<ARGV> entry in
+L<perlvar> and the C<readline> entry in L<perlfunc>.
 
 =over
 
@@ -174,14 +187,16 @@ test is considerably more sophisticated than:
 
 as it takes into account the magic behaviour of C<*ARGV>.
 
-You can also pass C<is_interactive> a writable filehandle, in which case it
-requires that filehandle be connected to a terminal (instead of the
-currently selected).  The usual suspect here is C<*STDERR>:
+You can also pass C<is_interactive> a writable filehandle, in which
+case it requires that filehandle be connected to a terminal (instead
+of the currently selected). The usual suspect here is C<*STDERR>:
 
     if ( is_interactive(*STDERR) ) {
         carp $warning;
     }
 
+Note that C<is_interactive> may return true in a Windows Scheduled
+Task. See Github #6 (https://github.com/briandfoy/io-interactive/issues/6).
 
 =item C<interactive()>
 
@@ -244,9 +259,8 @@ None reported.
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<bug-io-interactive@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+Please report any bugs or feature requests to Github
+L<https://github.com/briandfoy/io-interactive/issues>.
 
 =head1 SOURCE AVAILABILITY
 
@@ -258,13 +272,13 @@ This code is in GitHub:
 
 Damian Conway  C<< <DCONWAY@cpan.org> >>
 
-Currently maintained by brian d foy C<< <bdfoy@cpan.org> >>
+Currently maintained by brian d foy C<< <bdfoy@cpan.org> >>.
 
 1.01 patch DMUEY C<< dmuey@cpan.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2005, Damian Conway C<< <DCONWAY@cpan.org> >>. All rights reserved.
+Copyright © 2005-2021, Damian Conway C<< <DCONWAY@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
